aacgmv2._aacgmv2
================

This submodule contains the interface to the AACGM-v2 C library. For the user-friendly wrapper, see the functions in :py:module:`aacgmv2.wrapper`.

.. automodule:: aacgmv2._aacgmv2
    :members:
